4.18. umbra.components.factory.scriptEditor.nodes — Umbra 1.0.9 documentation

# 4.18. umbra.components.factory.scriptEditor.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class nodes.

Others:

## 4.18.1. Module Attributes

`umbra.components.factory.scriptEditor.nodes.` `LOGGER`

## 4.18.2. Classes

class `umbra.components.factory.scriptEditor.nodes.` `EditorNode`(editor=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Editor node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `editor`

    Property for self.__editor attribute.

    Returns: | self.__editor.
    Return type: | Editor

class `umbra.components.factory.scriptEditor.nodes.` `FileNode`(path=None, name=None, parent=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class File node.

  Initializes the class.

  Parameters: | path (unicode) – File path. name (unicode) – Node name. parent (GraphModelNode) – Node parent. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `path`

    Property for self.__path attribute.

    Returns: | self.__path.
    Return type: | unicode

class `umbra.components.factory.scriptEditor.nodes.` `DirectoryNode`(path=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Directory node.

  Initializes the class.

  Parameters: | path (unicode) – Directory path. name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `path`

    Property for self.__path attribute.

    Returns: | self.__path.
    Return type: | unicode

class `umbra.components.factory.scriptEditor.nodes.` `ProjectNode`(path=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Project node.

  Initializes the class.

  Parameters: | path (unicode) – Project path. name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `path`

    Property for self.__path attribute.

    Returns: | self.__path.
    Return type: | unicode

class `umbra.components.factory.scriptEditor.nodes.` `PatternNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.patterns.factory.scriptEditor.searchAndReplace.SearchAndReplace` class search and replace pattern node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

class `umbra.components.factory.scriptEditor.nodes.` `SearchFileNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class search file node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

class `umbra.components.factory.scriptEditor.nodes.` `SearchOccurenceNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class search occurence node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

class `umbra.components.factory.scriptEditor.nodes.` `ReplaceResultNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class replace result node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.